@@ -7,7 +7,7 @@
 #  define VTKINFOVISLAYOUT_NO_EXPORT
 #else
 #  ifndef VTKINFOVISLAYOUT_EXPORT
-#    ifdef vtkInfovisLayout_EXPORTS
+#    ifdef InfovisLayout_EXPORTS
         /* We are building this library */
 #      define VTKINFOVISLAYOUT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,26 @@
 
 #ifndef VTKINFOVISLAYOUT_DEPRECATED
 #  define VTKINFOVISLAYOUT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKINFOVISLAYOUT_DEPRECATED_EXPORT VTKINFOVISLAYOUT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKINFOVISLAYOUT_DEPRECATED_NO_EXPORT VTKINFOVISLAYOUT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKINFOVISLAYOUT_NO_DEPRECATED
+#ifndef VTKINFOVISLAYOUT_DEPRECATED_EXPORT
+#  define VTKINFOVISLAYOUT_DEPRECATED_EXPORT VTKINFOVISLAYOUT_EXPORT VTKINFOVISLAYOUT_DEPRECATED
 #endif
 
-
-
+#ifndef VTKINFOVISLAYOUT_DEPRECATED_NO_EXPORT
+#  define VTKINFOVISLAYOUT_DEPRECATED_NO_EXPORT VTKINFOVISLAYOUT_NO_EXPORT VTKINFOVISLAYOUT_DEPRECATED
 #endif
+
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKINFOVISLAYOUT_NO_DEPRECATED
+#    define VTKINFOVISLAYOUT_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkInfovisLayoutModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKINFOVISLAYOUT_EXPORT_H */
