@@ -33,10 +33,16 @@
 #  define VTKRENDERINGIMAGE_DEPRECATED_NO_EXPORT VTKRENDERINGIMAGE_NO_EXPORT VTKRENDERINGIMAGE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKRENDERINGIMAGE_NO_DEPRECATED
 #    define VTKRENDERINGIMAGE_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkRenderingImageModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKRENDERINGIMAGE_EXPORT_H */
